﻿using System;
using System.Collections.Generic;
using System.Web;
using C1.Web.Wijmo.Controls.C1GridView;
using System.Web.UI;
using System.Collections.Specialized;
using System.Collections;
using System.ComponentModel;
using System.Web.UI.WebControls;

namespace C1GridViewExt
{
    /// <summary>
    /// Summary description for C1GridViewExt
    /// </summary>
   [ToolboxData("<{0}:C1GridViewExt runat=server></{0}:C1GridViewExt>")]
    public class C1GridViewExtControl : C1GridView
    {
        private IBindableTemplate editItemTemplate;
        private bool enableFormEditing;

        public bool EnableFormEditing
        {
            get { return enableFormEditing; }
            set { enableFormEditing = value; }
        }

        [PersistenceMode(PersistenceMode.InnerProperty), TemplateContainer(typeof(C1GridViewRow), System.ComponentModel.BindingDirection.TwoWay)]
        public IBindableTemplate EditItemTemplate
        {
            set { editItemTemplate = value; }
            get { return editItemTemplate; }
        }


       protected override void ExtractRowValues(System.Collections.Specialized.IOrderedDictionary fieldValues, C1GridViewRow row, bool includeReadOnlyFields, bool includePrimaryKey)
        {

            if (enableFormEditing)
            {
                IOrderedDictionary dict = editItemTemplate.ExtractValues(row.Cells[0]);
                foreach (string s in dict.Keys)
                    fieldValues.Add(s, dict[s]);
            }
            else
                base.ExtractRowValues(fieldValues, row, includeReadOnlyFields, includePrimaryKey);
        }

       protected override void InitializeRow(C1GridViewRow row, List<C1BaseField> fields)
        {
            C1GridViewRowState state = row.RowState & C1GridViewRowState.Edit;
            if (row.RowType == C1GridViewRowType.DataRow && state != C1GridViewRowState.Normal && enableFormEditing == true)
            {
                int ColSpan = fields.Count;
                row.Cells.Clear();

                C1GridViewCell cell = new C1GridViewCell(fields[0]);
                cell.ColumnSpan = ColSpan;
                editItemTemplate.InstantiateIn(cell);
                row.Cells.Add(cell);
              
            }
            else

                base.InitializeRow(row, fields);
            
        }

       protected override void OnPreRender(EventArgs e)
       {
           base.OnPreRender(e);
           RegisterScript();
       }

       private void RegisterScript()
       {
           this.Page.ClientScript.RegisterStartupScript(this.GetType(), this.ID + "_script", "<script>$.fn.c1gridviewextcontrol = $.fn.c1gridview</script>");

       }

       protected override void OnInit(EventArgs e)
        {
            if (enableFormEditing && editItemTemplate == null)
                throw new Exception("EditTemplate Missing.");
            base.OnInit(e);
        }
    }
}